Enum style::matching::CascadeVisitedMode
[−]
[src]
pub enum CascadeVisitedMode {
Unvisited,
Visited,
}Determines which styles are being cascaded currently.
Variants
UnvisitedCascade the regular, unvisited styles.
VisitedCascade the styles used when an element's relevant link is visited. A "relevant link" is the element being matched if it is a link or the nearest ancestor link.
Methods
impl CascadeVisitedMode[src]
pub fn visited_dependent_only(&self) -> bool[src]
Returns whether the cascade should filter to only visited dependent properties based on the cascade mode.